@@ -71,13 +71,13 @@ matchit.qqplot <- function(x,discrete.cutoff,
       m.xi <- jitter(m.xi)
     }
     rr <- range(xi)
-    qqplot(xi[treat==0],xi[treat==1], xlim=rr,ylim=rr,axes=F,ylab="",xlab="")
+    eqqplot(xi[treat==0],xi[treat==1], xlim=rr,ylim=rr,axes=F,ylab="",xlab="")
     abline(a=0,b=1)
     abline(a=(rr[2]-rr[1])*0.1,b=1,lty=2)
     abline(a=-(rr[2]-rr[1])*0.1,b=1,lty=2)
     axis(2)
     box()
-    qqplot(m.xi[m.treat==0],m.xi[m.treat==1],xlim=rr,ylim=rr,axes=F,ylab="",xlab="")
+    eqqplot(m.xi[m.treat==0],m.xi[m.treat==1],xlim=rr,ylim=rr,axes=F,ylab="",xlab="")
     abline(a=0,b=1)
     abline(a=(rr[2]-rr[1])*0.1,b=1,lty=2)
     abline(a=-(rr[2]-rr[1])*0.1,b=1,lty=2)
