@@ -1,11 +1,8 @@
 matchit2full <- function(treat, X, data, distance, discarded,
                          verbose=FALSE, ...) { 
-  if ("optmatch" %in% .packages(all = TRUE))
-    require(optmatch)
-  else {
+  if (!("optmatch" %in% .packages(all = TRUE)))
     install.packages("optmatch", contriburl="http://www.stat.lsa.umich.edu/~bbh/optmatch")
-    require(optmatch)
-  }
+  require(optmatch)
   
   if(verbose)
     cat("Full matching... \n")
